## Digitize eggs that are represented as 3D meshes (.ply files or similar format)

  # The functions automatically calculate 6 points at the poles of the egg.
  # Then the build.egg.template finds n surface semilandmarks following algorithm outlined 
  # in Gunz et al. (2005) and Mitteroecker and Gunz (2009). 
  # Finally the template of n semilandmarks is fitted using thin-plate spline to the remaining eggs, and the semilandmarks 
  # on those eggs are found by a nearest-neighbour aproach.

  # Gunz P, Mitteroecker P, & Bookstein FJ (2005) Semilandmarks in Three Dimensions. Modern Morphometrics in Physical 
    # Anthropology, ed Slice DE (Springer-Verlag, New York), pp 73-98.
  # Mitteroecker P & Gunz P (2009) Advances in Geometric Morphometrics. Evolutionary Biology 36(2):235-247.

# Script and source files written by Emma Sherratt (emma.sherratt@gmail.com)
# Accompanying Attard et al. 2016 PeerJ

# 1. Set Working directory to the folder of the 3D meshes (.ply files or similar format)

# 2. Load functions for digitizing
  # must have the following libraries installed: rgl, Morpho, geometry
eggEnv <- new.env()
sys.source("Digitize eggs source.R", envir = eggEnv) 
attach(eggEnv )

# 3. First get names of all .ply files in folder
egglist <- list.files(pattern= ".ply")

# 4. Read in the first egg .ply file and re-orient by the principal axes:
   egg <- file2mesh(egglist[1]); plot3d(pcAlign(egg), asp=F, col="grey")
   
# 5. Build the template of surface-sliding semilandmarks.
   build.egg.template(egg, 200, ptsize=1) # here 200 equidistant semilandmarks will be calculated over the surface
  # The function returns to the working directory the following file:
   # "template.txt" This is the x,y,z coordinates of the semilandmark template, to be used by 'digit.egg.surface'

# 6. A loop to read in all egg .ply files and apply the template to digitize the eggs
for(i in 1:length(egglist)){
  spec <- file2mesh(egglist[i])
  digit.egg.surface(spec, ptsize=1, spec.name = sub(".ply", "", egglist[i]))  }
  # The function writes individual .nts files containing the x,y,z coordinates for every egg to the working directory

